diff --git a/README.markdown b/README.markdown
index 6ea94f8fb..97f352317 100644
--- a/README.markdown
+++ b/README.markdown
@@ -411,8 +411,25 @@ Feel free to contact commondream or wycats through GitHub with any other
 questions or feature requests. To submit changes fork the project and
 send a pull request.
 
+### Releasing
+
+Handlebars utilizes the [release yeoman generator][generator-release] to perform most release tasks.
+
+A full release may be completed with the following:
+
+```
+yo release:notes patch
+yo release:release patch
+npm publish
+yo release:publish cdnjs handlebars.js dist/cdnjs/
+yo release:publish components handlebars.js dist/components/
+```
+
+After this point the handlebars site needs to be updated to point to the new version numbers.
+
 License
 -------
 Handlebars.js is released under the MIT license.
 
 [builds-page]: http://builds.handlebarsjs.com.s3.amazonaws.com/index.html
+[generator-release]: https://github.com/walmartlabs/generator-release
diff --git a/bin/handlebars b/bin/handlebars
index 8ab6afda8..d51df92de 100755
--- a/bin/handlebars
+++ b/bin/handlebars
@@ -102,7 +102,7 @@ var optimist = require('optimist')
     });
 
 var fs = require('fs'),
-    handlebars = require('../lib/handlebars'),
+    handlebars = require('../lib'),
     basename = require('path').basename,
     uglify = require('uglify-js');
 
diff --git a/components/bower.json b/components/bower.json
index ee9011dd5..2631b5f3f 100644
--- a/components/bower.json
+++ b/components/bower.json
@@ -1,6 +1,6 @@
 {
   "name": "handlebars",
-  "version": "1.1.0",
+  "version": "1.1.1",
   "main": "handlebars.js",
   "dependencies": {}
 }
diff --git a/components/handlebars.js.nuspec b/components/handlebars.js.nuspec
index 07d097c73..0e8a1daf8 100644
--- a/components/handlebars.js.nuspec
+++ b/components/handlebars.js.nuspec
@@ -2,7 +2,7 @@
 <package>
 	<metadata>
 		<id>handlebars.js</id>
-		<version>1.1.0</version>
+		<version>1.1.1</version>
 		<authors>handlebars.js Authors</authors>
 		<licenseUrl>https://github.com/wycats/handlebars.js/blob/master/LICENSE</licenseUrl>
 		<projectUrl>https://github.com/wycats/handlebars.js/</projectUrl>
diff --git a/lib/handlebars/base.js b/lib/handlebars/base.js
index 236a3c272..f9d8aa934 100644
--- a/lib/handlebars/base.js
+++ b/lib/handlebars/base.js
@@ -2,7 +2,7 @@
 module Utils from "./utils";
 import Exception from "./exception";
 
-export var VERSION = "1.1.0";
+export var VERSION = "1.1.1";
 export var COMPILER_REVISION = 4;
 
 export var REVISION_CHANGES = {
diff --git a/package.json b/package.json
index 3e7595b39..d22c8c11b 100644
--- a/package.json
+++ b/package.json
@@ -1,7 +1,7 @@
 {
   "name": "handlebars",
   "barename": "handlebars",
-  "version": "1.1.0",
+  "version": "1.1.1",
   "description": "Handlebars provides the power necessary to let you build semantic templates effectively with no frustration",
   "homepage": "http://www.handlebarsjs.com/",
   "keywords": [
diff --git a/release-notes.md b/release-notes.md
index 6040f411f..58b3ead85 100644
--- a/release-notes.md
+++ b/release-notes.md
@@ -2,7 +2,15 @@
 
 ## Development
 
-[Commits](https://github.com/wycats/handlebars.js/compare/v1.1.0...master)
+[Commits](https://github.com/wycats/handlebars.js/compare/v1.1.1...master)
+
+## v1.1.1 - November 4th, 2013
+
+- [#642](https://github.com/wycats/handlebars.js/issues/642) - handlebars 1.1.0 are broken with nodejs
+
+- Fix release notes link - 17ba258
+
+[Commits](https://github.com/wycats/handlebars.js/compare/v1.1.0...v1.1.1)
 
 ## v1.1.0 - November 3rd, 2013
 
@@ -27,7 +35,7 @@ Compatibility notes:
   - AMD: Users may load the bundled `handlebars.amd.js` or `handlebars.runtime.amd.js` files or load individual modules directly. AMD users should also note that the handlebars object is exposed via the `default` field on the imported object. This [gist](https://gist.github.com/wycats/7417be0dc361a69d5916) provides some discussion of possible compatibility shims.
   - CommonJS/Node: Node loading occurs as normal via `require`
   - Globals: The `handlebars.js` and `handlebars.runtime.js` files should behave in the same manner as the v1.0.12 / 1.0.0 release.
-- Build artifacts have been removed from the repository. [npm][npm], [components/handlebars.js][components], [cdnjs][cdnjs-lib], or the [builds page][builds-page] should now be used as the source of built artifacts. 
+- Build artifacts have been removed from the repository. [npm][npm], [components/handlebars.js][components], [cdnjs][cdnjs], or the [builds page][builds-page] should now be used as the source of built artifacts. 
 - Context-stored helpers are now always passed the `options` hash. Previously no-argument helpers did not have this argument.
 
 
@@ -124,6 +132,6 @@ template(context, {helpers: helpers, partials: partials, data: data})
 ```
 
 [builds-page]: http://builds.handlebarsjs.com.s3.amazonaws.com/index.html
-[cdn-js]: http://cdnjs.com/libraries/handlebars.js/
+[cdnjs]: http://cdnjs.com/libraries/handlebars.js/
 [components]: https://github.com/components/handlebars.js
 [npm]: https://npmjs.org/package/handlebars
